#
# spec file for package python-jupyter_nbconvert
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_nbconvert
Version:        5.3.1
Release:        4.9
Summary:        Converting Jupyter Notebooks
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/nbconvert
Source:         https://files.pythonhosted.org/packages/source/n/nbconvert/nbconvert-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-Pygments
Requires:       python-bleach
Requires:       python-entrypoints >= 0.2.2
Requires:       python-jupyter_core
Requires:       python-jupyter_nbformat >= 4.4
Requires:       python-mistune >= 0.7.4
Requires:       python-pandocfilters >= 1.4.1
Requires:       python-testpath
Requires:       python-traitlets >= 4.2
Recommends:     pandoc
Recommends:     python-jupyter_client >= 4.2
Recommends:     python-tornado >= 4.0
Suggests:       %{name}-latex
BuildArch:      noarch
%python_subpackages

%description
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

%package        latex
Summary:        LaTeX support for nbconvert
Group:          Development/Languages/Python
Requires:       texlive-bibtex
Requires:       texlive-makeindex
Requires:       tex(adjustbox.sty)
Requires:       tex(eurosym.sty)
Requires:       tex(ulem.sty)

%description    latex
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

This package pulls in the LaTeX dependencies for nbconvert.

%prep
%setup -q -n nbconvert-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/nbconvert/nbconvertapp.py
chmod a+x %{buildroot}%{$python_sitelib}/nbconvert/filters/filter_links.py
sed -i "s|^#!%{_bindir}/env python$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/nbconvert/nbconvertapp.py
sed -i "s|^#!%{_bindir}/env python3$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/nbconvert/filters/filter_links.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/filters/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/filters/
%fdupes %{buildroot}%{$python_sitelib}
}

%files %{python_files}
%license LICENSE
%doc README.md
%python3_only %{_bindir}/jupyter-nbconvert
%{python_sitelib}/*

%files %{python_files latex}
%license LICENSE
%doc README.md

%changelog
* Thu Jul 26 2018 mcepl@suse.com
- Clean up SPEC file.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.3.1
  * MANIFEST.in updated to include ``LICENSE`` and ``scripts/`` when creating sdist. #666
- Update to 5.3
  + Major features
  * Tag Based Element Filtering
  + new features
  * configurable ``browser`` in ServePostProcessor #618
  * ``--clear-output`` command line flag to clear output in-place #619
  * remove elements based on tags with ``TagRemovePreprocessor``. #640, #643
  * CellExecutionError can now be imported from ``nbconvert.preprocessors`` #656
  * slides now can enable scrolling and custom transitions #600
  + Documentation
  * Release instructions for nbviewer-deploy
  * improved instructions for handling errors using the ``ExecutePreprocessor`` #656
  + Testing
  * better height/width metadata testing for images in rst & html #601 #602
  * normalise base64 output data to avoid false positives #650
  * normalise ipython traceback messages to handle old and new style #631
  + Bugfixes
  * mathjax obeys ``\\(\\)`` & ``\\[\\]`` (both nbconvert & pandoc) #609 #617
  * specify default templates using extensions #639
  * fix pandoc version number #638
  * require recent mistune version #630
  * catch errors from IPython ``execute_reply`` and ``error`` messages #642
  + Other
  * nose completely removed & dependency dropped #595 #660
  * mathjax processing in mistune now only uses inline grammar #611
  * removeRegex now enabled by default on all TemplateExporters, does not remove cells with outputs #616
  * validate notebook after applying each preprocessor (allowing additional attributes) #645
  * changed COPYING.md to LICENSE for more standard licensing that GitHub knows how to read #654
- Update to 5.2
  + Major features
  * Global Content Filtering
  * Execute notebooks from a function
  * Remove cells based on regex pattern
  * Script exporter entrypoints for nonpython scripts
  + New features
  * configurable ExecutePreprocessor.startup_timeout configurable #583
  * RemoveCell preprocessor based on cell content (defaults to empty cell) #575
  * function for executing notebooks: `executenb` #573
  * global filtering to remove inputs, outputs, markdown cells (&c.), this works on all templates #554
  * script exporter entrypoint #531
  * configurable anchor link text (previously ¶) `HTMLExporter.anchor_link_text` #522
  * configurable values for slides exporter #542 #558
  + Bugfixes
  * we now respect width and height metadata on jpeg and png mimetype outputs #588
  * now we respect the `resolve_references` filter in `report.tplx` #577
  * output metadata now is removed by ClearOutputPreprocessor #569
  * display id respected in execute preproessor #563
  * dynamic defaults for optional jupyter_client import #559
  * don't self-close non-void HTML tags #548
  * upgrade jupyter_client dependency to 4.2 #539
  * LaTeX output through md→LaTeX conversion shouldn't be touched #535
  * now we escape `<` inside math formulas when converting to html #514
  + Other
  * improved releases (how-to documentation, version-number generation and checking) #593
  * doc improvements  #593 #580 #565 #554
  * language information from cell magics (for highlighting) is now included in more formats #586
  * mathjax upgrades and cdn fixes #584 #567
  * better CI #571 #540
  * better traceback behaviour when execution errs #521
  * deprecated nose test features removed #519
* Wed Sep 13 2017 jmatejek@suse.com
- switch texlive Recommends to Suggests - let's not pull the whole
  texlive for this particular package
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 5.1.1
  * fix version numbering because of incomplete previous version number
- Update to 5.1
  * improved CSS (specifically tables, in line with notebook) #498
  * improve in-memory templates handling #491
  * test improvements #516 #509 #505
  * new configuration option: IOPub timeout #513
  * doc improvements #489 #500 #493 #506
  * newly customizable: output prompt #500
  * more python2/3 compatibile unicode handling #502
- Update to 5.0
  * Use :command:`xelatex` by default for latex export, improving unicode and font support.
  * Use entrypoints internally to access Exporters, allowing for packages to declare custom exporters more easily.
  * New ASCIIDoc Exporter.
  * New preprocessor for sanitised html output.
  * New general ``convert_pandoc`` filter to reduce the need to hard-code lists of filters in templates.
  * Use pytest, nose dependency to be removed.
  * Refactored Exporter code to avoid ambiguity and cyclic dependencies.
  * Update to traitlets 4.2 API.
  * Fixes for Unicode errors when showing execution errors on Python 2.
  * Default math font matches default Palatino body text font.
  * General documentation improvements. For example, testing, installation, custom exporters.
  * Improved link handling for LaTeX output
  * Refactored the automatic id generation.
  * New kernel_manager_class configuration option for allowing systems to be set up to resolve kernels in different ways.
  * Kernel errors now will be logged for debugging purposes when executing notebooks.
- Update to 4.3
  * added live widget rendering for html output, nbviewer by extension
- Update to 4.2
  * :ref:`Custom Exporters <external_exporters>` can be provided by external packages,
  and registered with nbconvert via setuptools entrypoints.
  * allow nbconvert reading from stdin with ``--stdin`` option (write into
  ``notebook`` basename)
  * Various ANSI-escape fixes and improvements
  * Various LaTeX/PDF export fixes
  * Various fixes and improvements for executing notebooks with ``--execute``.
- Create doc subpackage
* Mon Mar  7 2016 toddrme2178@gmail.com
- Update to 4.1.0
  * setuptools fixes for entrypoints on Windows
  * various fixes for exporters, including slides, latex, and PDF
  * fixes for exceptions met during execution
  * include markdown outputs in markdown/html exports
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
